==> zio-aws-appsync_2.12-6.20.42.1-sources.jar: zio/aws/appsync/model/EvaluateCodeResponse.scala <==
package zio.aws.appsync.model
import zio.aws.appsync.model.primitives.EvaluationResult
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EvaluateCodeResponse(
    evaluationResult: Optional[EvaluationResult] = Optional.Absent,
    error: Optional[zio.aws.appsync.model.EvaluateCodeErrorDetail] =
      Optional.Absent,
    logs: Optional[Iterable[String]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.EvaluateCodeResponse = {
    import EvaluateCodeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.EvaluateCodeResponse
      .builder()
      .optionallyWith(
        evaluationResult.map(value =>
          EvaluationResult.unwrap(value): java.lang.String
        )
      )(_.evaluationResult)
      .optionallyWith(error.map(value => value.buildAwsValue()))(_.error)
      .optionallyWith(
        logs.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.logs)
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.EvaluateCodeResponse.ReadOnly =
    zio.aws.appsync.model.EvaluateCodeResponse.wrap(buildAwsValue())
}
object EvaluateCodeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.EvaluateCodeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.EvaluateCodeResponse =
      zio.aws.appsync.model.EvaluateCodeResponse(
        evaluationResult.map(value => value),
        error.map(value => value.asEditable),
        logs.map(value => value)
      )
    def evaluationResult: Optional[EvaluationResult]
    def error: Optional[zio.aws.appsync.model.EvaluateCodeErrorDetail.ReadOnly]
    def logs: Optional[List[String]]
    def getEvaluationResult: ZIO[Any, AwsError, EvaluationResult] =
      AwsError.unwrapOptionField("evaluationResult", evaluationResult)
    def getError: ZIO[
      Any,
      AwsError,
      zio.aws.appsync.model.EvaluateCodeErrorDetail.ReadOnly
    ] = AwsError.unwrapOptionField("error", error)
    def getLogs: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("logs", logs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.EvaluateCodeResponse
  ) extends zio.aws.appsync.model.EvaluateCodeResponse.ReadOnly {
    override val evaluationResult: Optional[EvaluationResult] =
      zio.aws.core.internal
        .optionalFromNullable(impl.evaluationResult())
        .map(value => zio.aws.appsync.model.primitives.EvaluationResult(value))
    override val error
        : Optional[zio.aws.appsync.model.EvaluateCodeErrorDetail.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.error())
        .map(value => zio.aws.appsync.model.EvaluateCodeErrorDetail.wrap(value))
    override val logs: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.logs())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.EvaluateCodeResponse
  ): zio.aws.appsync.model.EvaluateCodeResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appsync_3-6.20.74.1-sources.jar: zio/aws/appsync/model/EvaluateCodeResponse.scala <==
package zio.aws.appsync.model
import zio.aws.appsync.model.primitives.EvaluationResult
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class EvaluateCodeResponse(
    evaluationResult: Optional[EvaluationResult] = Optional.Absent,
    error: Optional[zio.aws.appsync.model.EvaluateCodeErrorDetail] =
      Optional.Absent,
    logs: Optional[Iterable[String]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.EvaluateCodeResponse = {
    import EvaluateCodeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.EvaluateCodeResponse
      .builder()
      .optionallyWith(
        evaluationResult.map(value =>
          EvaluationResult.unwrap(value): java.lang.String
        )
      )(_.evaluationResult)
      .optionallyWith(error.map(value => value.buildAwsValue()))(_.error)
      .optionallyWith(
        logs.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.logs)
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.EvaluateCodeResponse.ReadOnly =
    zio.aws.appsync.model.EvaluateCodeResponse.wrap(buildAwsValue())
}
object EvaluateCodeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.EvaluateCodeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.EvaluateCodeResponse =
      zio.aws.appsync.model.EvaluateCodeResponse(
        evaluationResult.map(value => value),
        error.map(value => value.asEditable),
        logs.map(value => value)
      )
    def evaluationResult: Optional[EvaluationResult]
    def error: Optional[zio.aws.appsync.model.EvaluateCodeErrorDetail.ReadOnly]
    def logs: Optional[List[String]]
    def getEvaluationResult: ZIO[Any, AwsError, EvaluationResult] =
      AwsError.unwrapOptionField("evaluationResult", evaluationResult)
    def getError: ZIO[
      Any,
      AwsError,
      zio.aws.appsync.model.EvaluateCodeErrorDetail.ReadOnly
    ] = AwsError.unwrapOptionField("error", error)
    def getLogs: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("logs", logs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.EvaluateCodeResponse
  ) extends zio.aws.appsync.model.EvaluateCodeResponse.ReadOnly {
    override val evaluationResult: Optional[EvaluationResult] =
      zio.aws.core.internal
        .optionalFromNullable(impl.evaluationResult())
        .map(value => zio.aws.appsync.model.primitives.EvaluationResult(value))
    override val error
        : Optional[zio.aws.appsync.model.EvaluateCodeErrorDetail.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.error())
        .map(value => zio.aws.appsync.model.EvaluateCodeErrorDetail.wrap(value))
    override val logs: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.logs())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.EvaluateCodeResponse
  ): zio.aws.appsync.model.EvaluateCodeResponse.ReadOnly = new Wrapper(impl)
}
